import React, { Component } from 'react';
import moment from 'moment';
import classnames from 'classnames';
import { Modal, Table } from 'antd';
import AnimTableBody from '../../components/Animation/AnimTableBody';
import styles from './table.less';

const confirm = Modal.confirm;

export default class CampusTableList extends Component {

  handleDeleteItem = (record) => {
    confirm({
      title: '您确定要删除该校区吗?',
      onOk () {
        onDeleteItem(record.id);
      },
    });
  }

  render() {
    const {
      onDeleteItem,
      onEditItem,
      location,
      pagination,
      curMerchant,
      merchantList = [],
      ...tableProps
    } = this.props;

    const columns = [{
      title: '校区编号',
      dataIndex: 'code',
      key: 'code',
    },{
      title: '校区名称',
      dataIndex: 'name',
      key: 'name',
    },{
      title: '渠道名称',
      dataIndex: 'merchantId',
      key: 'merchantId',
      render: (text, record) => record.merchantName,
      filters: merchantList.map(item => ({ text: item.name, value: item.id })),
      filterMultiple: false,
      filteredValue: [curMerchant],
    },{
      title: '联系人',
      dataIndex: 'contactName',
      key: 'contactName',
    },{
      title: '电话',
      dataIndex: 'mobile',
      key: 'mobile',
    },{
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: (text, record) => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      )
    },{
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
        </div>
      )
    }];

    // 数据table列表表头的筛选按钮点击重置后status与domain值为空，此时删除该参数
    columns.map(item => {
      item.dataIndex === 'merchantId' && !curMerchant ? delete item.filteredValue : null;
    });

    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条`};
    const getBodyWrapperProps = {
      page: tableProps.pagination.page,
      current: tableProps.pagination.current,
    };
    const getBodyWrapper = (body) => (<AnimTableBody {...getBodyWrapperProps} body={body} />);

    return (
      <Table
        simple
        bordered
        { ...tableProps }
        columns={columns}
        className={classnames({ [styles.table]: true, [styles.motion]: true })}
        rowKey={record => record.id}
        getBodyWrapper={getBodyWrapper}
      />
    );
  }
}
